@@ -36,7 +36,7 @@ use static_math::matrix4x4::M44;
 
 fn inverse6x6_test() {
 
-    let m = M66::new([
+    let m = M66::<f32>::new([
         [1.0, 1.0, 3.0, 4.0, 9.0, 3.0],
         [10.0, 10.0, 1.0, 2.0, 2.0, 5.0],
         [2.0, 9.0, 6.0, 10.0, 10.0, 9.0],
@@ -51,7 +51,7 @@ fn inverse6x6_test() {
 
 fn inverse4x4_test() {
 
-    let m = M44::new([
+    let m = M44::<f32>::new([
         [1.0, 1.0, 1.0, -1.0],
         [1.0, 1.0, -1.0, 1.0],
         [1.0, -1.0, 1.0, 1.0],
