@@ -293,6 +293,12 @@ impl<T: Num + fmt::Display> fmt::Display for V3<T> {
     }
 }
 
+//-------------------------------------------------------------------------
+//                        constants
+//-------------------------------------------------------------------------
+pub const X_AXIS: V3<f32> = V3::new_from(1.0, 0.0, 0.0);
+pub const Y_AXIS: V3<f32> = V3::new_from(0.0, 1.0, 0.0);
+pub const Z_AXIS: V3<f32> = V3::new_from(0.0, 0.0, 1.0);
 //-------------------------------------------------------------------------
 //                        tests
 //-------------------------------------------------------------------------
