@@ -50,8 +50,8 @@ impl<T> V5<T> {
     }
 
     /// create a new V5 from raw numbers
-    pub const fn new_from(a: T, b: T, c: T, d: T, e: T) -> Self {
-        Self::new([a, b, c, d, e])
+    pub const fn new_from(num1: T, num2: T, num3: T, num4: T, num5: T) -> Self {
+        Self::new([num1, num2, num3, num4, num5])
     }
 }
 
